% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/missingValuesFilter.R
\name{mvFilterGetIndices}
\alias{mvFilterGetIndices}
\title{Filter lines in the matrix of intensities w.r.t. some criteria}
\usage{
mvFilterGetIndices(
  obj,
  percent = FALSE,
  condition = "WholeMatrix",
  threshold = NULL
)
}
\arguments{
\item{obj}{An object of class \code{MSnSet} containing
quantitative data.}

\item{percent}{TRUE or FALSE. Default is FALSE..}

\item{condition}{Method used to choose the lines to delete.
Values are : "None", "EmptyLines", "WholeMatrix", "AllCond", "AtLeastOneCond"}

\item{threshold}{An integer value of the threshold if percent is FALSE. Otherwise, a floating
number between 0 and 1.}
}
\value{
An vector of indices that correspond to the lines to keep.
}
\description{
Returns the indices of the lines of \code{exprs()} table to delete w.r.t. 
the conditions on the number of missing values.
The user chooses the minimum amount of intensities that is acceptable and
the filter delete lines that do not respect this condition.
The condition may be on the whole line or condition by condition.
}
\details{
The different methods are :
"WholeMatrix": given a threshold \code{th}, only the lines that contain
at least \code{th} values are kept.
"AllCond": given a threshold \code{th}, only the lines which contain
at least \code{th} values for each of the conditions are kept.
"AtLeastOneCond": given a threshold \code{th}, only the lines that contain
at least \code{th} values, and for at least one condition, are kept.
}
\examples{
utils::data(Exp1_R25_pept, package='DAPARdata')
keepThat <- mvFilterGetIndices(Exp1_R25_pept, condition = "WholeMatrix", threshold=2)
keepThat <- mvFilterGetIndices(Exp1_R25_pept, condition = "EmptyLines")
keepThat <- mvFilterGetIndices(Exp1_R25_pept, condition = "WholeMatrix", percent=TRUE, threshold=0.5)

}
\author{
Enora Fremy, Samuel Wieczorek
}
